/*
 * © 2017 LogMeIn, Inc. All Rights Reserved.
 * All rights reserved.
 * 
 * This software is distributed under the terms and conditions of the
 * LogMeIn SDK License Agreement. Please see file LICENSE for details.
 * 
 * Auto-generated file.
 */


using System;
using System.Collections.Generic;
using LogMeIn.GoToMeeting.Api.Common;
using LogMeIn.GoToMeeting.Api.Model;


namespace LogMeIn.GoToMeeting.Api
{
    /// <summary>
    ///
    /// </summary>
    public class GroupsApi
    {
        private string basePath = "https://api.getgo.com/G2M/rest";
        private readonly ApiInvoker apiInvoker = ApiInvoker.GetInstance();

        /// <summary>
        /// Initializes a new instance of the GroupsApi class using the
        /// default endpoint base url for the services being accessed.
        /// </summary>
        public GroupsApi()
        {
        }

        /// <summary>
        /// Initializes a new instance of the GroupsApi class using an endpoint base
        /// url other than the default. Use this constructor only if you should need
        /// to override the default endpoint base url.
        /// </summary>
        /// <param name="basePath">The endpoint base url for the services being accessed.</param>
        public GroupsApi(String basePath)
        {
            this.basePath = basePath;
        }

        /// <summary>
        /// Gets the API invoker
        /// </summary>
        public ApiInvoker Invoker
        {
            get { return apiInvoker; }
        }

        /// <summary>
        /// Gets the endpoint base url for the services being accessed
        /// </summary>
        public String BasePath
        {
            get { return basePath; }
        }

        /// <summary>
        /// Create organizer in group
        /// Creates a new organizer and sends an email to the email address defined in request. This API call is only available to users with the admin role. You may also pass 'G2W' or 'G2T' or 'OPENVOICE' as productType variables, creating organizers for those products. A G2W or G2T organizer will also have access to G2M.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="groupKey">The key of the group</param>
        /// <param name="body">The details of the organizer to be created</param>
        /// <returns>List&lt;OrganizerShort&gt;</returns>
        /// <exception cref="ApiException"></exception>
        public List<OrganizerShort> createOrganizer(string authorization, long? groupKey, OrganizerReq body)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (groupKey == null)
                throw new ApiException("Required parameter groupKey is null.");

            if (body == null)
                throw new ApiException("Required parameter body is null.");

            // create path and map variables
            var path = "/groups/{groupKey}/organizers"
                .Replace("{format}", "json")
                .Replace("{" + "groupKey" + "}", apiInvoker.EscapeString(groupKey.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "POST", queryParams, body, headerParams, formParams, typeof(List<OrganizerShort>), contentType);
            if (response != null)
                return (List<OrganizerShort>)response;

            return null;
        }

        /// <summary>
        /// Get attendees by group
        /// Returns all attendees for all meetings within specified date range held by organizers within the specified group. This API call is only available to users with the admin role. This API call can be used only for groups with maximum 50 organizers.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="groupKey">The key of the group</param>
        /// <param name="startDate">Start of date range, in ISO8601 UTC format, e.g. 2015-07-01T22:00:00Z</param>
        /// <param name="endDate">End of date range, in ISO8601 UTC format, e.g. 2015-07-01T23:00:00Z</param>
        /// <returns>List&lt;AttendeeByGroup&gt;</returns>
        /// <exception cref="ApiException"></exception>
        public List<AttendeeByGroup> getAttendeesByGroup(string authorization, long? groupKey, DateTime? startDate, DateTime? endDate)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (groupKey == null)
                throw new ApiException("Required parameter groupKey is null.");

            // create path and map variables
            var path = "/groups/{groupKey}/attendees"
                .Replace("{format}", "json")
                .Replace("{" + "groupKey" + "}", apiInvoker.EscapeString(groupKey.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            if (startDate != null)
                queryParams.Add("startDate", startDate.Stringify());

            if (endDate != null)
                queryParams.Add("endDate", endDate.Stringify());

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<AttendeeByGroup>), contentType);
            if (response != null)
                return (List<AttendeeByGroup>)response;

            return null;
        }

        /// <summary>
        /// Get groups
        /// List all groups for an account. This API call is only available to users with the admin role.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <returns>List&lt;Group&gt;</returns>
        /// <exception cref="ApiException"></exception>
        public List<Group> getGroups(string authorization)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            // create path and map variables
            var path = "/groups"
                .Replace("{format}", "json");

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<Group>), contentType);
            if (response != null)
                return (List<Group>)response;

            return null;
        }

        /// <summary>
        /// Get historical meetings by group
        /// Get historical meetings for the specified group that started within the specified date/time range. This API call is only available to users with the admin role. This API call is restricted to groups with a maximum of 50 organizers. Remark: Meetings which are still ongoing at the time of the request are NOT contained in the result array.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="groupKey">The key of the group</param>
        /// <param name="startDate">Required start of date range, in ISO8601 UTC format, e.g. 2015-07-01T22:00:00Z</param>
        /// <param name="endDate">Required end of date range, in ISO8601 UTC format, e.g. 2015-07-01T23:00:00Z</param>
        /// <returns>List&lt;HistoricalMeetingByGroup&gt;</returns>
        /// <exception cref="ApiException"></exception>
        public List<HistoricalMeetingByGroup> getHistoricalMeetingsByGroup(string authorization, long? groupKey, DateTime? startDate, DateTime? endDate)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (groupKey == null)
                throw new ApiException("Required parameter groupKey is null.");

            if (startDate == null)
                throw new ApiException("Required parameter startDate is null.");

            if (endDate == null)
                throw new ApiException("Required parameter endDate is null.");

            // create path and map variables
            var path = "/groups/{groupKey}/historicalMeetings"
                .Replace("{format}", "json")
                .Replace("{" + "groupKey" + "}", apiInvoker.EscapeString(groupKey.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            if (startDate != null)
                queryParams.Add("startDate", startDate.Stringify());

            if (endDate != null)
                queryParams.Add("endDate", endDate.Stringify());

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<HistoricalMeetingByGroup>), contentType);
            if (response != null)
                return (List<HistoricalMeetingByGroup>)response;

            return null;
        }

        /// <summary>
        /// DEPRECATED: Get historical meetings by group
        /// DEPRECATED: Please use the new API calls 'Get historical meetings by group' and 'Get upcoming meetings by group'. Get meetings for a specified group. Additional filters can be used to view only meetings within a specified date range. This API call is only available to users with the admin role.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="groupKey">The key of the group</param>
        /// <param name="history">When 'true', returns all past meetings within date range</param>
        /// <param name="startDate">If history=true, required start of date range, in ISO8601 UTC format, e.g. 2015-07-01T22:00:00Z</param>
        /// <param name="endDate">If history=true, required end of date range, in ISO8601 UTC format, e.g. 2015-07-01T23:00:00Z</param>
        /// <returns>List&lt;HistoryMeetingByGroup&gt;</returns>
        /// <exception cref="ApiException"></exception>
        [Obsolete]
        public List<HistoryMeetingByGroup> getHistoryMeetingsByGroup(string authorization, long? groupKey, bool? history, DateTime? startDate, DateTime? endDate)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (groupKey == null)
                throw new ApiException("Required parameter groupKey is null.");

            if (history == null)
                throw new ApiException("Required parameter history is null.");

            if (startDate == null)
                throw new ApiException("Required parameter startDate is null.");

            if (endDate == null)
                throw new ApiException("Required parameter endDate is null.");

            // create path and map variables
            var path = "/groups/{groupKey}/meetings"
                .Replace("{format}", "json")
                .Replace("{" + "groupKey" + "}", apiInvoker.EscapeString(groupKey.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            if (history != null)
                queryParams.Add("history", history.Stringify());

            if (startDate != null)
                queryParams.Add("startDate", startDate.Stringify());

            if (endDate != null)
                queryParams.Add("endDate", endDate.Stringify());

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<HistoryMeetingByGroup>), contentType);
            if (response != null)
                return (List<HistoryMeetingByGroup>)response;

            return null;
        }

        /// <summary>
        /// Get organizers by group
        /// Returns all the organizers within a specific group. This API call is only available to users with the admin role.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="groupKey">The key of the group</param>
        /// <returns>List&lt;OrganizerByGroup&gt;</returns>
        /// <exception cref="ApiException"></exception>
        public List<OrganizerByGroup> getOrganizersByGroup(string authorization, long? groupKey)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (groupKey == null)
                throw new ApiException("Required parameter groupKey is null.");

            // create path and map variables
            var path = "/groups/{groupKey}/organizers"
                .Replace("{format}", "json")
                .Replace("{" + "groupKey" + "}", apiInvoker.EscapeString(groupKey.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<OrganizerByGroup>), contentType);
            if (response != null)
                return (List<OrganizerByGroup>)response;

            return null;
        }

        /// <summary>
        /// Get upcoming meetings by group
        /// Get upcoming meetings for a specified group. This API call is only available to users with the admin role. This API call can be used only for groups with maximum 50 organizers.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="groupKey">The key of the group</param>
        /// <returns>List&lt;UpcomingMeetingByGroup&gt;</returns>
        /// <exception cref="ApiException"></exception>
        public List<UpcomingMeetingByGroup> getUpcomingMeetingsByGroup(string authorization, long? groupKey)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (groupKey == null)
                throw new ApiException("Required parameter groupKey is null.");

            // create path and map variables
            var path = "/groups/{groupKey}/upcomingMeetings"
                .Replace("{format}", "json")
                .Replace("{" + "groupKey" + "}", apiInvoker.EscapeString(groupKey.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<UpcomingMeetingByGroup>), contentType);
            if (response != null)
                return (List<UpcomingMeetingByGroup>)response;

            return null;
        }

        /// <summary>
        /// Get scheduled meetings by group
        /// Get scheduled meetings for a group. This API is only available to corporate users with the admin role.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="groupKey">The key of the group</param>
        /// <param name="scheduled">When 'true' returns all future meetings</param>
        /// <param name="startDate">If history=true, required start of date range, in ISO8601 UTC format</param>
        /// <param name="endDate">If history=true, required end of date range, in ISO8601 UTC format</param>
        /// <returns>List&lt;ScheduledMeetingByGroup&gt; </returns>
        [Obsolete("Use getUpcomingMeetingsByGroup() instead.", false)]
        public List<ScheduledMeetingByGroup> getScheduledMeetingsByGroup(string authorization, long? groupKey, bool? scheduled, DateTime? startDate, DateTime? endDate)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (groupKey == null)
                throw new ApiException("Required parameter groupKey is null.");

            if (scheduled == null)
                throw new ApiException("Required parameter scheduled is null.");

            if (startDate == null)
                throw new ApiException("Required parameter startDate is null.");

            if (endDate == null)
                throw new ApiException("Required parameter endDate is null.");

            // create path and map variables
            var path = "/groups/{groupKey}/meetings"
                .Replace("{format}", "json")
                .Replace("{" + "groupKey" + "}", apiInvoker.EscapeString(groupKey.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            if (scheduled != null)
                queryParams.Add("scheduled", scheduled.Stringify());

            if (startDate != null)
                queryParams.Add("startDate", startDate.Stringify());

            if (endDate != null)
                queryParams.Add("endDate", endDate.Stringify());

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes[0];

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<ScheduledMeetingByGroup>), contentType);
            if (response != null)
                return (List<ScheduledMeetingByGroup>)response;

            return null;
        }

    }
}
