/*
 * © 2017 LogMeIn, Inc. All Rights Reserved.
 * All rights reserved.
 * 
 * This software is distributed under the terms and conditions of the
 * LogMeIn SDK License Agreement. Please see file LICENSE for details.
 * 
 * Auto-generated file.
 */


using System;
using System.Collections.Generic;
using LogMeIn.GoToMeeting.Api.Common;
using LogMeIn.GoToMeeting.Api.Model;


namespace LogMeIn.GoToMeeting.Api
{
    /// <summary>
    ///
    /// </summary>
    public class MeetingsApi
    {
        private string basePath = "https://api.getgo.com/G2M/rest";
        private readonly ApiInvoker apiInvoker = ApiInvoker.GetInstance();

        /// <summary>
        /// Initializes a new instance of the MeetingsApi class using the
        /// default endpoint base url for the services being accessed.
        /// </summary>
        public MeetingsApi()
        {
        }

        /// <summary>
        /// Initializes a new instance of the MeetingsApi class using an endpoint base
        /// url other than the default. Use this constructor only if you should need
        /// to override the default endpoint base url.
        /// </summary>
        /// <param name="basePath">The endpoint base url for the services being accessed.</param>
        public MeetingsApi(String basePath)
        {
            this.basePath = basePath;
        }

        /// <summary>
        /// Gets the API invoker
        /// </summary>
        public ApiInvoker Invoker
        {
            get { return apiInvoker; }
        }

        /// <summary>
        /// Gets the endpoint base url for the services being accessed
        /// </summary>
        public String BasePath
        {
            get { return basePath; }
        }

        /// <summary>
        /// Create meeting
        /// Create a new meeting based on the parameters specified.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="body">The meeting details</param>
        /// <returns>List&lt;MeetingCreated&gt;</returns>
        /// <exception cref="ApiException"></exception>
        public List<MeetingCreated> createMeeting(string authorization, MeetingReqCreate body)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (body == null)
                throw new ApiException("Required parameter body is null.");

            // create path and map variables
            var path = "/meetings"
                .Replace("{format}", "json");

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "POST", queryParams, body, headerParams, formParams, typeof(List<MeetingCreated>), contentType);
            if (response != null)
                return (List<MeetingCreated>)response;

            return null;
        }

        /// <summary>
        /// Delete meeting
        /// Deletes the meeting identified by the meetingId.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="meetingId">The meeting ID</param>
        /// <returns>void</returns>
        /// <exception cref="ApiException"></exception>
        public void deleteMeeting(string authorization, long? meetingId)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (meetingId == null)
                throw new ApiException("Required parameter meetingId is null.");

            // create path and map variables
            var path = "/meetings/{meetingId}"
                .Replace("{format}", "json")
                .Replace("{" + "meetingId" + "}", apiInvoker.EscapeString(meetingId.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            apiInvoker.InvokeAPI(basePath, path, "DELETE", queryParams, null, headerParams, formParams, typeof(void), contentType);
        }

        /// <summary>
        /// Get attendees by meeting
        /// List all attendees for specified meetingId of historical meeting. The historical meetings can be fetched using 'Get historical meetings', 'Get historical meetings by organizer', and 'Get historical meetings by group'. For users with the admin role this call returns attendees for any meeting. For any other user the call will return attendees for meetings on which the user is a valid organizer.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="meetingId">The meeting ID</param>
        /// <returns>List&lt;AttendeeByMeeting&gt;</returns>
        /// <exception cref="ApiException"></exception>
        public List<AttendeeByMeeting> getAttendeesByMeetings(string authorization, long? meetingId)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (meetingId == null)
                throw new ApiException("Required parameter meetingId is null.");

            // create path and map variables
            var path = "/meetings/{meetingId}/attendees"
                .Replace("{format}", "json")
                .Replace("{" + "meetingId" + "}", apiInvoker.EscapeString(meetingId.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<AttendeeByMeeting>), contentType);
            if (response != null)
                return (List<AttendeeByMeeting>)response;

            return null;
        }

        /// <summary>
        /// Get historical meetings
        /// Get historical meetings for the currently authenticated organizer that started within the specified date/time range. Remark: Meetings which are still ongoing at the time of the request are NOT contained in the result array.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="startDate">Required start of date range, in ISO8601 UTC format, e.g. 2015-07-01T22:00:00Z</param>
        /// <param name="endDate">Required end of date range, in ISO8601 UTC format, e.g. 2015-07-01T23:00:00Z</param>
        /// <returns>List&lt;HistoricalMeeting&gt;</returns>
        /// <exception cref="ApiException"></exception>
        public List<HistoricalMeeting> getHistoricalMeetings(string authorization, DateTime? startDate, DateTime? endDate)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (startDate == null)
                throw new ApiException("Required parameter startDate is null.");

            if (endDate == null)
                throw new ApiException("Required parameter endDate is null.");

            // create path and map variables
            var path = "/historicalMeetings"
                .Replace("{format}", "json");

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            if (startDate != null)
                queryParams.Add("startDate", startDate.Stringify());

            if (endDate != null)
                queryParams.Add("endDate", endDate.Stringify());

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<HistoricalMeeting>), contentType);
            if (response != null)
                return (List<HistoricalMeeting>)response;

            return null;
        }

        /// <summary>
        /// DEPRECATED: Get historical meetings
        /// DEPRECATED: Please use the new API calls 'Get historical meetings' and 'Get upcoming meetings'.  Gets historical meetings for the current authenticated organizer. Requires date range for filtering results to only meetings within specified dates. History searches will contain the parameter 'meetingInstanceKey' which is used in conjunction with the call 'Get Attendees by Meeting' to get attendee information for a past meeting.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="history">When 'true', returns all past meetings within date range</param>
        /// <param name="startDate">If history=true, required start of date range, in ISO8601 UTC format, e.g. 2015-07-01T22:00:00Z</param>
        /// <param name="endDate">If history=true, required end of date range, in ISO8601 UTC format, e.g. 2015-07-01T23:00:00Z</param>
        /// <returns>List&lt;MeetingHistory&gt;</returns>
        /// <exception cref="ApiException"></exception>
        [Obsolete]
        public List<MeetingHistory> getHistoryMeetings(string authorization, bool? history, DateTime? startDate, DateTime? endDate)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            // create path and map variables
            var path = "/meetings"
                .Replace("{format}", "json");

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            if (history != null)
                queryParams.Add("history", history.Stringify());

            if (startDate != null)
                queryParams.Add("startDate", startDate.Stringify());

            if (endDate != null)
                queryParams.Add("endDate", endDate.Stringify());

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<MeetingHistory>), contentType);
            if (response != null)
                return (List<MeetingHistory>)response;

            return null;
        }

        /// <summary>
        /// Get meeting
        /// Returns the meeting details for the specified meeting.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="meetingId">The meeting ID</param>
        /// <returns>List&lt;MeetingById&gt;</returns>
        /// <exception cref="ApiException"></exception>
        public List<MeetingById> getMeeting(string authorization, long? meetingId)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (meetingId == null)
                throw new ApiException("Required parameter meetingId is null.");

            // create path and map variables
            var path = "/meetings/{meetingId}"
                .Replace("{format}", "json")
                .Replace("{" + "meetingId" + "}", apiInvoker.EscapeString(meetingId.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<MeetingById>), contentType);
            if (response != null)
                return (List<MeetingById>)response;

            return null;
        }

        /// <summary>
        /// Get upcoming meetings
        /// Gets upcoming meetings for the current authenticated organizer.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <returns>List&lt;UpcomingMeeting&gt;</returns>
        /// <exception cref="ApiException"></exception>
        public List<UpcomingMeeting> getUpcomingMeetings(string authorization)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            // create path and map variables
            var path = "/upcomingMeetings"
                .Replace("{format}", "json");

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<UpcomingMeeting>), contentType);
            if (response != null)
                return (List<UpcomingMeeting>)response;

            return null;
        }

        /// <summary>
        /// Start meeting
        /// Returns a host URL that can be used to start a meeting. When this URL is opened in a web browser, the GoToMeeting client will be downloaded and launched and the meeting will start. The end user is not required to login to a client.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="meetingId">The meeting ID</param>
        /// <returns>StartUrl</returns>
        /// <exception cref="ApiException"></exception>
        public StartUrl startMeeting(string authorization, long? meetingId)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (meetingId == null)
                throw new ApiException("Required parameter meetingId is null.");

            // create path and map variables
            var path = "/meetings/{meetingId}/start"
                .Replace("{format}", "json")
                .Replace("{" + "meetingId" + "}", apiInvoker.EscapeString(meetingId.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(StartUrl), contentType);
            if (response != null)
                return (StartUrl)response;

            return null;
        }

        /// <summary>
        /// Update meeting
        /// Updates an existing meeting specified by meetingId.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="meetingId">The meeting ID</param>
        /// <param name="body">The meeting details</param>
        /// <returns>void</returns>
        /// <exception cref="ApiException"></exception>
        public void updateMeeting(string authorization, long? meetingId, MeetingReqUpdate body)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (meetingId == null)
                throw new ApiException("Required parameter meetingId is null.");

            if (body == null)
                throw new ApiException("Required parameter body is null.");

            // create path and map variables
            var path = "/meetings/{meetingId}"
                .Replace("{format}", "json")
                .Replace("{" + "meetingId" + "}", apiInvoker.EscapeString(meetingId.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            apiInvoker.InvokeAPI(basePath, path, "PUT", queryParams, body, headerParams, formParams, typeof(void), contentType);
        }

        /// <summary>
        /// Get scheduled meetings
        /// Gets scheduled meetings (meetings that have not occurred) for a specified organizer.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="scheduled">When 'true' returns all future meetings</param>
        /// <returns>List&lt;MeetingScheduled&gt; </returns>
        [Obsolete("Use getUpcomingMeetings() instead", false)]
        public List<MeetingScheduled> getScheduledMeetings(string authorization, bool? scheduled)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            // create path and map variables
            var path = "/meetings".Replace("{format}", "json");

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            if (scheduled != null)
                queryParams.Add("scheduled", scheduled.Stringify());

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes[0];

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<MeetingScheduled>), contentType);
            if (response != null)
                return (List<MeetingScheduled>)response;

            return null;
        }

    }
}
