/*
 * © 2017 LogMeIn, Inc. All Rights Reserved.
 * All rights reserved.
 * 
 * This software is distributed under the terms and conditions of the
 * LogMeIn SDK License Agreement. Please see file LICENSE for details.
 * 
 * Auto-generated file.
 */


using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using LogMeIn.GoToMeeting.Api.Common;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;


namespace LogMeIn.GoToMeeting.Api.Model
{
    /// <summary>
    /// Describes an attendee of a meeting instance held by an organizer within a specified group.
    /// </summary>
    public class AttendeeByGroup
    {
        /// <summary>
        /// The surname of the meeting organizer
        /// </summary>
        public string lastName { get; set; }

        /// <summary>
        /// The name of the group
        /// </summary>
        public string groupName { get; set; }

        /// <summary>
        /// The number of attendees at the attended meeting instance
        /// </summary>
        public int? numAttendees { get; set; }

        /// <summary>
        /// The full name of the attendee
        /// </summary>
        public string attendeeName { get; set; }

        /// <summary>
        /// The subject of the attended meeting
        /// </summary>
        public string subject { get; set; }

        /// <summary>
        /// The time the meeting instance ended
        /// </summary>
        public DateTime? endTime { get; set; }

        /// <summary>
        /// Audio options for the attended meeting
        /// </summary>
        public string conferenceCallInfo { get; set; }

        /// <summary>
        /// The key of the meeting organizer. Field retained for backwards compatibility reasons
        /// </summary>
        public long? organizerkey { get; set; }

        /// <summary>
        /// The time the meeting instance started
        /// </summary>
        public DateTime? startTime { get; set; }

        /// <summary>
        /// The key of the attended meeting instance
        /// </summary>
        public long? meetingInstanceKey { get; set; }

        /// <summary>
        /// The duration of attendance in minutes
        /// </summary>
        public int? duration { get; set; }

        /// <summary>
        /// The time the attendee joined the meeting instance
        /// </summary>
        public DateTime? joinTime { get; set; }

        /// <summary>
        /// The email address of the meeting organizer
        /// </summary>
        public string email { get; set; }

        /// <summary>
        /// The time the attendee left the meeting instance
        /// </summary>
        public DateTime? leaveTime { get; set; }

        /// <summary>
        /// The attendee's email address
        /// </summary>
        public string attendeeEmail { get; set; }

        /// <summary>
        /// The key of the meeting organizer
        /// </summary>
        public string organizerKey { get; set; }

        /// <summary>
        /// The meeting ID
        /// </summary>
        public string meetingId { get; set; }

        /// <summary>
        /// The meeting type
        /// </summary>
        [JsonConverter(typeof(StringEnumConverter))]
        public MeetingType? meetingType { get; set; }

        /// <summary>
        /// The first name of the organizer of the attended meeting
        /// </summary>
        public string firstName { get; set; }


        /// <summary>
        /// Returns a string representing the current object.
        /// </summary>
        /// <returns>The Json serialization of the current object.</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class AttendeeByGroup {\n");
            var lastNameString = lastName.Stringify();
            if (!string.IsNullOrEmpty(lastNameString))
                sb.AppendFormat("  lastName: {0}\n", lastNameString);
            var groupNameString = groupName.Stringify();
            if (!string.IsNullOrEmpty(groupNameString))
                sb.AppendFormat("  groupName: {0}\n", groupNameString);
            var numAttendeesString = numAttendees.Stringify();
            if (!string.IsNullOrEmpty(numAttendeesString))
                sb.AppendFormat("  numAttendees: {0}\n", numAttendeesString);
            var attendeeNameString = attendeeName.Stringify();
            if (!string.IsNullOrEmpty(attendeeNameString))
                sb.AppendFormat("  attendeeName: {0}\n", attendeeNameString);
            var subjectString = subject.Stringify();
            if (!string.IsNullOrEmpty(subjectString))
                sb.AppendFormat("  subject: {0}\n", subjectString);
            var endTimeString = endTime.Stringify();
            if (!string.IsNullOrEmpty(endTimeString))
                sb.AppendFormat("  endTime: {0}\n", endTimeString);
            var conferenceCallInfoString = conferenceCallInfo.Stringify();
            if (!string.IsNullOrEmpty(conferenceCallInfoString))
                sb.AppendFormat("  conferenceCallInfo: {0}\n", conferenceCallInfoString);
            var organizerkeyString = organizerkey.Stringify();
            if (!string.IsNullOrEmpty(organizerkeyString))
                sb.AppendFormat("  organizerkey: {0}\n", organizerkeyString);
            var startTimeString = startTime.Stringify();
            if (!string.IsNullOrEmpty(startTimeString))
                sb.AppendFormat("  startTime: {0}\n", startTimeString);
            var meetingInstanceKeyString = meetingInstanceKey.Stringify();
            if (!string.IsNullOrEmpty(meetingInstanceKeyString))
                sb.AppendFormat("  meetingInstanceKey: {0}\n", meetingInstanceKeyString);
            var durationString = duration.Stringify();
            if (!string.IsNullOrEmpty(durationString))
                sb.AppendFormat("  duration: {0}\n", durationString);
            var joinTimeString = joinTime.Stringify();
            if (!string.IsNullOrEmpty(joinTimeString))
                sb.AppendFormat("  joinTime: {0}\n", joinTimeString);
            var emailString = email.Stringify();
            if (!string.IsNullOrEmpty(emailString))
                sb.AppendFormat("  email: {0}\n", emailString);
            var leaveTimeString = leaveTime.Stringify();
            if (!string.IsNullOrEmpty(leaveTimeString))
                sb.AppendFormat("  leaveTime: {0}\n", leaveTimeString);
            var attendeeEmailString = attendeeEmail.Stringify();
            if (!string.IsNullOrEmpty(attendeeEmailString))
                sb.AppendFormat("  attendeeEmail: {0}\n", attendeeEmailString);
            var organizerKeyString = organizerKey.Stringify();
            if (!string.IsNullOrEmpty(organizerKeyString))
                sb.AppendFormat("  organizerKey: {0}\n", organizerKeyString);
            var meetingIdString = meetingId.Stringify();
            if (!string.IsNullOrEmpty(meetingIdString))
                sb.AppendFormat("  meetingId: {0}\n", meetingIdString);
            var meetingTypeString = meetingType.Stringify();
            if (!string.IsNullOrEmpty(meetingTypeString))
                sb.AppendFormat("  meetingType: {0}\n", meetingTypeString);
            var firstNameString = firstName.Stringify();
            if (!string.IsNullOrEmpty(firstNameString))
                sb.AppendFormat("  firstName: {0}\n", firstNameString);
            sb.Append("}\n");
            return sb.ToString();
        }
    }

}
