/*
 * © 2017 LogMeIn, Inc. All Rights Reserved.
 * All rights reserved.
 * 
 * This software is distributed under the terms and conditions of the
 * LogMeIn SDK License Agreement. Please see file LICENSE for details.
 * 
 * Auto-generated file.
 */


using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using LogMeIn.GoToMeeting.Api.Common;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;


namespace LogMeIn.GoToMeeting.Api.Model
{
    /// <summary>
    /// Describes a unique past meeting instance.
    /// </summary>
    public class MeetingHistory
    {
        /// <summary>
        /// The surname of the meeting organizer
        /// </summary>
        public string lastName { get; set; }

        /// <summary>
        /// DEPRECATED. An empty string '' is returned
        /// </summary>
        [Obsolete]
        public string groupName { get; set; }

        /// <summary>
        /// The number of attendees at the meeting instance
        /// </summary>
        public int? numAttendees { get; set; }

        /// <summary>
        /// DEPRECATED. An empty string '' is returned
        /// </summary>
        [Obsolete]
        public bool? passwordRequired { get; set; }

        /// <summary>
        /// DEPRECATED. An empty string '' is returned
        /// </summary>
        [Obsolete]
        public string status { get; set; }

        /// <summary>
        /// The subject of the meeting
        /// </summary>
        public string subject { get; set; }

        /// <summary>
        /// The time the meeting instance ended
        /// </summary>
        public DateTime? endTime { get; set; }

        /// <summary>
        /// The time the meeting instance started. Field retained for backwards compatibility reasons
        /// </summary>
        public DateTime? date { get; set; }

        /// <summary>
        /// Audio options for the meeting
        /// </summary>
        public string conferenceCallInfo { get; set; }

        /// <summary>
        /// The time the meeting instance started
        /// </summary>
        public DateTime? startTime { get; set; }

        /// <summary>
        /// The key of the meeting organizer. Field retained for backwards compatibility reasons
        /// </summary>
        public string organizerkey { get; set; }

        /// <summary>
        /// The key of the unique meeting instance
        /// </summary>
        public long? meetingInstanceKey { get; set; }

        /// <summary>
        /// The key of the meeting organizer. Field introduced for compatibility reasons
        /// </summary>
        public string newOrganizerKey { get; set; }

        /// <summary>
        /// The duration of the meeting session in minutes
        /// </summary>
        public int? duration { get; set; }

        /// <summary>
        /// Formatted meeting ID
        /// </summary>
        public string newMeetingId { get; set; }

        /// <summary>
        /// The ID of the meeting session
        /// </summary>
        public long? sessionId { get; set; }

        /// <summary>
        /// The meeting organizer's email address
        /// </summary>
        public string email { get; set; }

        /// <summary>
        /// The meeting ID
        /// </summary>
        public long? meetingId { get; set; }

        /// <summary>
        /// The key of the meeting organizer
        /// </summary>
        public string organizerKey { get; set; }

        /// <summary>
        /// The meeting ID. Field retained for backwards compatibility reasons
        /// </summary>
        public long? meetingKey { get; set; }

        /// <summary>
        /// The meeting type
        /// </summary>
        [JsonConverter(typeof(StringEnumConverter))]
        public MeetingType? meetingType { get; set; }

        /// <summary>
        /// The meeting organizer's first name
        /// </summary>
        public string firstName { get; set; }

        /// <summary>
        /// The meeting ID. Field retained for backwards compatibility reasons
        /// </summary>
        public long? uniqueMeetingId { get; set; }

        /// <summary>
        /// Information about the meeting recording
        /// </summary>
        public MeetingRecording recording { get; set; }


        /// <summary>
        /// Returns a string representing the current object.
        /// </summary>
        /// <returns>The Json serialization of the current object.</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class MeetingHistory {\n");
            var lastNameString = lastName.Stringify();
            if (!string.IsNullOrEmpty(lastNameString))
                sb.AppendFormat("  lastName: {0}\n", lastNameString);
            var groupNameString = groupName.Stringify();
            if (!string.IsNullOrEmpty(groupNameString))
                sb.AppendFormat("  groupName: {0}\n", groupNameString);
            var numAttendeesString = numAttendees.Stringify();
            if (!string.IsNullOrEmpty(numAttendeesString))
                sb.AppendFormat("  numAttendees: {0}\n", numAttendeesString);
            var passwordRequiredString = passwordRequired.Stringify();
            if (!string.IsNullOrEmpty(passwordRequiredString))
                sb.AppendFormat("  passwordRequired: {0}\n", passwordRequiredString);
            var statusString = status.Stringify();
            if (!string.IsNullOrEmpty(statusString))
                sb.AppendFormat("  status: {0}\n", statusString);
            var subjectString = subject.Stringify();
            if (!string.IsNullOrEmpty(subjectString))
                sb.AppendFormat("  subject: {0}\n", subjectString);
            var endTimeString = endTime.Stringify();
            if (!string.IsNullOrEmpty(endTimeString))
                sb.AppendFormat("  endTime: {0}\n", endTimeString);
            var dateString = date.Stringify();
            if (!string.IsNullOrEmpty(dateString))
                sb.AppendFormat("  date: {0}\n", dateString);
            var conferenceCallInfoString = conferenceCallInfo.Stringify();
            if (!string.IsNullOrEmpty(conferenceCallInfoString))
                sb.AppendFormat("  conferenceCallInfo: {0}\n", conferenceCallInfoString);
            var startTimeString = startTime.Stringify();
            if (!string.IsNullOrEmpty(startTimeString))
                sb.AppendFormat("  startTime: {0}\n", startTimeString);
            var organizerkeyString = organizerkey.Stringify();
            if (!string.IsNullOrEmpty(organizerkeyString))
                sb.AppendFormat("  organizerkey: {0}\n", organizerkeyString);
            var meetingInstanceKeyString = meetingInstanceKey.Stringify();
            if (!string.IsNullOrEmpty(meetingInstanceKeyString))
                sb.AppendFormat("  meetingInstanceKey: {0}\n", meetingInstanceKeyString);
            var newOrganizerKeyString = newOrganizerKey.Stringify();
            if (!string.IsNullOrEmpty(newOrganizerKeyString))
                sb.AppendFormat("  newOrganizerKey: {0}\n", newOrganizerKeyString);
            var durationString = duration.Stringify();
            if (!string.IsNullOrEmpty(durationString))
                sb.AppendFormat("  duration: {0}\n", durationString);
            var newMeetingIdString = newMeetingId.Stringify();
            if (!string.IsNullOrEmpty(newMeetingIdString))
                sb.AppendFormat("  newMeetingId: {0}\n", newMeetingIdString);
            var sessionIdString = sessionId.Stringify();
            if (!string.IsNullOrEmpty(sessionIdString))
                sb.AppendFormat("  sessionId: {0}\n", sessionIdString);
            var emailString = email.Stringify();
            if (!string.IsNullOrEmpty(emailString))
                sb.AppendFormat("  email: {0}\n", emailString);
            var meetingIdString = meetingId.Stringify();
            if (!string.IsNullOrEmpty(meetingIdString))
                sb.AppendFormat("  meetingId: {0}\n", meetingIdString);
            var organizerKeyString = organizerKey.Stringify();
            if (!string.IsNullOrEmpty(organizerKeyString))
                sb.AppendFormat("  organizerKey: {0}\n", organizerKeyString);
            var meetingKeyString = meetingKey.Stringify();
            if (!string.IsNullOrEmpty(meetingKeyString))
                sb.AppendFormat("  meetingKey: {0}\n", meetingKeyString);
            var meetingTypeString = meetingType.Stringify();
            if (!string.IsNullOrEmpty(meetingTypeString))
                sb.AppendFormat("  meetingType: {0}\n", meetingTypeString);
            var firstNameString = firstName.Stringify();
            if (!string.IsNullOrEmpty(firstNameString))
                sb.AppendFormat("  firstName: {0}\n", firstNameString);
            var uniqueMeetingIdString = uniqueMeetingId.Stringify();
            if (!string.IsNullOrEmpty(uniqueMeetingIdString))
                sb.AppendFormat("  uniqueMeetingId: {0}\n", uniqueMeetingIdString);
            var recordingString = recording.Stringify();
            if (!string.IsNullOrEmpty(recordingString))
                sb.AppendFormat("  recording: {0}\n", recordingString);
            sb.Append("}\n");
            return sb.ToString();
        }
    }

}
