/*
 * © 2017 LogMeIn, Inc. All Rights Reserved.
 * All rights reserved.
 * 
 * This software is distributed under the terms and conditions of the
 * LogMeIn SDK License Agreement. Please see file LICENSE for details.
 * 
 * Auto-generated file.
 */


using System;
using System.Collections.Generic;
using LogMeIn.GoToMeeting.Api.Common;
using LogMeIn.GoToMeeting.Api.Model;


namespace LogMeIn.GoToMeeting.Api
{
    /// <summary>
    ///
    /// </summary>
    public class OrganizersApi
    {
        private string basePath = "https://api.getgo.com/G2M/rest";
        private readonly ApiInvoker apiInvoker = ApiInvoker.GetInstance();

        /// <summary>
        /// Initializes a new instance of the OrganizersApi class using the
        /// default endpoint base url for the services being accessed.
        /// </summary>
        public OrganizersApi()
        {
        }

        /// <summary>
        /// Initializes a new instance of the OrganizersApi class using an endpoint base
        /// url other than the default. Use this constructor only if you should need
        /// to override the default endpoint base url.
        /// </summary>
        /// <param name="basePath">The endpoint base url for the services being accessed.</param>
        public OrganizersApi(String basePath)
        {
            this.basePath = basePath;
        }

        /// <summary>
        /// Gets the API invoker
        /// </summary>
        public ApiInvoker Invoker
        {
            get { return apiInvoker; }
        }

        /// <summary>
        /// Gets the endpoint base url for the services being accessed
        /// </summary>
        public String BasePath
        {
            get { return basePath; }
        }

        /// <summary>
        /// Create organizer
        /// Creates a new organizer and sends an email to the email address defined in the request. This API call is only available to users with the admin role. You may also pass 'G2W' or 'G2T' or 'OPENVOICE' as productType variables, creating organizers for those products. A G2W or G2T organizer will also have access to G2M.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="body">The details of the organizer to be created</param>
        /// <returns>List&lt;OrganizerShort&gt;</returns>
        /// <exception cref="ApiException"></exception>
        public List<OrganizerShort> createOrganizer(string authorization, OrganizerReq body)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (body == null)
                throw new ApiException("Required parameter body is null.");

            // create path and map variables
            var path = "/organizers"
                .Replace("{format}", "json");

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "POST", queryParams, body, headerParams, formParams, typeof(List<OrganizerShort>), contentType);
            if (response != null)
                return (List<OrganizerShort>)response;

            return null;
        }

        /// <summary>
        /// Delete organizer
        /// Deletes the individual organizer specified by the organizer key. This API call is only available to users with the admin role.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="organizerKey">The key of the organizer</param>
        /// <returns>void</returns>
        /// <exception cref="ApiException"></exception>
        public void deleteOrganizer(string authorization, long? organizerKey)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (organizerKey == null)
                throw new ApiException("Required parameter organizerKey is null.");

            // create path and map variables
            var path = "/organizers/{organizerKey}"
                .Replace("{format}", "json")
                .Replace("{" + "organizerKey" + "}", apiInvoker.EscapeString(organizerKey.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            apiInvoker.InvokeAPI(basePath, path, "DELETE", queryParams, null, headerParams, formParams, typeof(void), contentType);
        }

        /// <summary>
        /// Delete organizer by email
        /// Deletes the individual organizer specified by the email address. This API call is only available to users with the admin role.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="email">The email address of the organizer</param>
        /// <returns>void</returns>
        /// <exception cref="ApiException"></exception>
        public void deleteOrganizerByEmail(string authorization, string email)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (email == null)
                throw new ApiException("Required parameter email is null.");

            // create path and map variables
            var path = "/organizers"
                .Replace("{format}", "json");

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            if (email != null)
                queryParams.Add("email", email.Stringify());

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            apiInvoker.InvokeAPI(basePath, path, "DELETE", queryParams, null, headerParams, formParams, typeof(void), contentType);
        }

        /// <summary>
        /// Remove attendee list of a meeting session
        /// Use this call to clean up your data by deleting the attendee list for a specific session. The sessionID(s) and the number of attendees at each session is included by meeting in the Get Historical Meetings call. Each meeting held is at least one session. One meeting may be multiple sessions if the organizer stopped and restarted the meeting for any reason, such as their device of choice did not work. Recurring meetings are at least one session per event. The call removes the attendee list from the session from LogMeIn's servers. You can remove the entire session data using the Delete Session call, or delete recordings of the meeting using the Delete Session Recordings call. The meeting will still appear in your organizer's Meeting History, but will have no associated attendees. NOTE: The delete occurs at the session level because this provides the greatest granular control. To delete for a specific meetingID, you would need to accumualate all sessions for the meeting and apply the delete.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="organizerKey">The organizer ID</param>
        /// <param name="sessionId">The session ID</param>
        /// <returns>void</returns>
        /// <exception cref="ApiException"></exception>
        public void deleteSessionAttendeesById(string authorization, long? organizerKey, long? sessionId)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (organizerKey == null)
                throw new ApiException("Required parameter organizerKey is null.");

            if (sessionId == null)
                throw new ApiException("Required parameter sessionId is null.");

            // create path and map variables
            var path = "/organizers/{organizerKey}/sessions/{sessionId}/attendees"
                .Replace("{format}", "json")
                .Replace("{" + "organizerKey" + "}", apiInvoker.EscapeString(organizerKey.ToString()))
                .Replace("{" + "sessionId" + "}", apiInvoker.EscapeString(sessionId.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            apiInvoker.InvokeAPI(basePath, path, "DELETE", queryParams, null, headerParams, formParams, typeof(void), contentType);
        }

        /// <summary>
        /// Delete meeting session by session id
        /// Use this call to clean up your data by deleting any specific session. The sessionID(s) are included by meeting in the Get Historical Meetings call. Each meeting held is at least one session. One meeting may be multiple sessions if the organizer stopped and restarted the meeting for any reason, such as their device of choice did not work. Recurring meetings are at least one session per event. The call removes the specified session(s) from LogMeIn's servers including the sessionID, the attendee list, and any recordings. The meeting will still appear in your organizer's Meeting History, but will have no associated sessions. NOTE: The delete occurs at the session level because this provides the greatest granular control. To delete for a specific meetingID, you would need to accumualate all sessions for the meeting and apply the delete.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="organizerKey">The organizer ID</param>
        /// <param name="sessionId">The session ID</param>
        /// <returns>void</returns>
        /// <exception cref="ApiException"></exception>
        public void deleteSessionById(string authorization, long? organizerKey, long? sessionId)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (organizerKey == null)
                throw new ApiException("Required parameter organizerKey is null.");

            if (sessionId == null)
                throw new ApiException("Required parameter sessionId is null.");

            // create path and map variables
            var path = "/organizers/{organizerKey}/sessions/{sessionId}"
                .Replace("{format}", "json")
                .Replace("{" + "organizerKey" + "}", apiInvoker.EscapeString(organizerKey.ToString()))
                .Replace("{" + "sessionId" + "}", apiInvoker.EscapeString(sessionId.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            apiInvoker.InvokeAPI(basePath, path, "DELETE", queryParams, null, headerParams, formParams, typeof(void), contentType);
        }

        /// <summary>
        /// Delete recordings of a meeting session
        /// Use this call to clean up your data by deleting recordings associated with a specific session. The sessionID(s) are included by meeting in the Get Historical Meetings call. The call removes any recordings associated with the specified session from LogMeIn's servers. (Any session may have multiple recordings if the feature was started and stopped multiple times during the meeting.) You can remove the entire session data using the Delete Session call, or delete attendee lists for the session using the Delete Session Attendees call. The meeting will still appear in your organizer's Meeting History, but will have no associated recordings for the specified session. NOTE: The delete occurs at the session level because this provides the greatest granular control. To delete for a specific meetingID, you would need to accumualate all sessions for the meeting and apply the delete.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="organizerKey">The organizer ID</param>
        /// <param name="sessionId">The session ID</param>
        /// <returns>void</returns>
        /// <exception cref="ApiException"></exception>
        public void deleteSessionRecordingsById(string authorization, long? organizerKey, long? sessionId)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (organizerKey == null)
                throw new ApiException("Required parameter organizerKey is null.");

            if (sessionId == null)
                throw new ApiException("Required parameter sessionId is null.");

            // create path and map variables
            var path = "/organizers/{organizerKey}/sessions/{sessionId}/recordings"
                .Replace("{format}", "json")
                .Replace("{" + "organizerKey" + "}", apiInvoker.EscapeString(organizerKey.ToString()))
                .Replace("{" + "sessionId" + "}", apiInvoker.EscapeString(sessionId.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            apiInvoker.InvokeAPI(basePath, path, "DELETE", queryParams, null, headerParams, formParams, typeof(void), contentType);
        }

        /// <summary>
        /// Get attendees by organizer
        /// Lists all attendees for all meetings within a specified date range for a specified organizer. This API call is only available to users with the admin role.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="organizerKey">The key of the organizer</param>
        /// <param name="startDate">A required start of date range in ISO8601 UTC format, e.g. 2015-07-01T22:00:00Z</param>
        /// <param name="endDate">A required end of date range in ISO8601 UTC format, e.g. 2015-07-01T23:00:00Z</param>
        /// <returns>List&lt;AttendeeByOrganizer&gt;</returns>
        /// <exception cref="ApiException"></exception>
        public List<AttendeeByOrganizer> getAttendeesByOrganizer(string authorization, long? organizerKey, DateTime? startDate, DateTime? endDate)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (organizerKey == null)
                throw new ApiException("Required parameter organizerKey is null.");

            if (startDate == null)
                throw new ApiException("Required parameter startDate is null.");

            if (endDate == null)
                throw new ApiException("Required parameter endDate is null.");

            // create path and map variables
            var path = "/organizers/{organizerKey}/attendees"
                .Replace("{format}", "json")
                .Replace("{" + "organizerKey" + "}", apiInvoker.EscapeString(organizerKey.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            if (startDate != null)
                queryParams.Add("startDate", startDate.Stringify());

            if (endDate != null)
                queryParams.Add("endDate", endDate.Stringify());

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<AttendeeByOrganizer>), contentType);
            if (response != null)
                return (List<AttendeeByOrganizer>)response;

            return null;
        }

        /// <summary>
        /// Get historical meetings by organizer
        /// Get historical meetings for the specified organizer that started within the specified date/time range. Remark: Meetings which are still ongoing at the time of the request are NOT contained in the result array.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="organizerKey">The key of the organizer</param>
        /// <param name="startDate">Required start of date range, in ISO8601 UTC format, e.g. 2015-07-01T22:00:00Z</param>
        /// <param name="endDate">Required end of date range, in ISO8601 UTC format, e.g. 2015-07-01T23:00:00Z</param>
        /// <returns>List&lt;HistoricalMeeting&gt;</returns>
        /// <exception cref="ApiException"></exception>
        public List<HistoricalMeeting> getHistoricalMeetingsByOrganizer(string authorization, long? organizerKey, DateTime? startDate, DateTime? endDate)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (organizerKey == null)
                throw new ApiException("Required parameter organizerKey is null.");

            if (startDate == null)
                throw new ApiException("Required parameter startDate is null.");

            if (endDate == null)
                throw new ApiException("Required parameter endDate is null.");

            // create path and map variables
            var path = "/organizers/{organizerKey}/historicalMeetings"
                .Replace("{format}", "json")
                .Replace("{" + "organizerKey" + "}", apiInvoker.EscapeString(organizerKey.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            if (startDate != null)
                queryParams.Add("startDate", startDate.Stringify());

            if (endDate != null)
                queryParams.Add("endDate", endDate.Stringify());

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<HistoricalMeeting>), contentType);
            if (response != null)
                return (List<HistoricalMeeting>)response;

            return null;
        }

        /// <summary>
        /// DEPRECATED: Get meetings by organizer
        /// DEPRECATED: Please use the new API calls 'Get historical meetings by organizer' and 'Get upcoming meetings by organizer'. Gets future (scheduled) or past (history) meetings for a specified organizer. Include 'history=true' and the past start and end dates in the URL to retrieve past meetings. Enter 'scheduled=true' (without dates) to get scheduled meetings.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="organizerKey">The key of the organizer</param>
        /// <param name="scheduled">When 'true', returns all future meetings. Date range not supported.</param>
        /// <param name="history">When 'true', returns all past meetings within date range</param>
        /// <param name="startDate">If history is 'true', required start of date range, in ISO8601 UTC format, e.g. 2015-07-01T22:00:00Z</param>
        /// <param name="endDate">If history is 'true', required end of date range, in ISO8601 UTC format, e.g. 2015-07-01T23:00:00Z</param>
        /// <returns>List&lt;MeetingByOrganizer&gt;</returns>
        /// <exception cref="ApiException"></exception>
        [Obsolete]
        public List<MeetingByOrganizer> getMeetingsByOrganizer(string authorization, long? organizerKey, bool? scheduled, bool? history, DateTime? startDate, DateTime? endDate)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (organizerKey == null)
                throw new ApiException("Required parameter organizerKey is null.");

            // create path and map variables
            var path = "/organizers/{organizerKey}/meetings"
                .Replace("{format}", "json")
                .Replace("{" + "organizerKey" + "}", apiInvoker.EscapeString(organizerKey.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            if (scheduled != null)
                queryParams.Add("scheduled", scheduled.Stringify());

            if (history != null)
                queryParams.Add("history", history.Stringify());

            if (startDate != null)
                queryParams.Add("startDate", startDate.Stringify());

            if (endDate != null)
                queryParams.Add("endDate", endDate.Stringify());

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<MeetingByOrganizer>), contentType);
            if (response != null)
                return (List<MeetingByOrganizer>)response;

            return null;
        }

        /// <summary>
        /// Get organizer
        /// Returns the individual organizer specified by the key. This API call is only available to users with the admin role. Non-admin users can only make this call for their own organizerKey.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="organizerKey">The key of the organizer</param>
        /// <returns>List&lt;Organizer&gt;</returns>
        /// <exception cref="ApiException"></exception>
        public List<Organizer> getOrganizer(string authorization, long? organizerKey)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (organizerKey == null)
                throw new ApiException("Required parameter organizerKey is null.");

            // create path and map variables
            var path = "/organizers/{organizerKey}"
                .Replace("{format}", "json")
                .Replace("{" + "organizerKey" + "}", apiInvoker.EscapeString(organizerKey.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<Organizer>), contentType);
            if (response != null)
                return (List<Organizer>)response;

            return null;
        }

        /// <summary>
        /// Get organizer by email / Get all organizers
        /// Gets the individual organizer specified by the organizer's email address. If an email address is not specified, all organizers are returned. This API call is only available to users with the admin role.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="email">The email address of the organizer</param>
        /// <returns>List&lt;Organizer&gt;</returns>
        /// <exception cref="ApiException"></exception>
        public List<Organizer> getOrganizersAllOrByEmail(string authorization, string email)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            // create path and map variables
            var path = "/organizers"
                .Replace("{format}", "json");

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            if (email != null)
                queryParams.Add("email", email.Stringify());

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<Organizer>), contentType);
            if (response != null)
                return (List<Organizer>)response;

            return null;
        }

        /// <summary>
        /// Get upcoming meetings by organizer
        /// Get upcoming meetings for a specified organizer. This API call is only available to users with the admin role.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="organizerKey">The key of the organizer</param>
        /// <returns>List&lt;UpcomingMeeting&gt;</returns>
        /// <exception cref="ApiException"></exception>
        public List<UpcomingMeeting> getUpcomingMeetingsByOrganizer(string authorization, long? organizerKey)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (organizerKey == null)
                throw new ApiException("Required parameter organizerKey is null.");

            // create path and map variables
            var path = "/organizers/{organizerKey}/upcomingMeetings"
                .Replace("{format}", "json")
                .Replace("{" + "organizerKey" + "}", apiInvoker.EscapeString(organizerKey.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<UpcomingMeeting>), contentType);
            if (response != null)
                return (List<UpcomingMeeting>)response;

            return null;
        }

        /// <summary>
        /// Update organizer
        /// Updates the products of the specified organizer. To add a product (G2M, G2W, G2T, OPENVOICE) for the organizer, the call must be sent once for each product you want to add. To remove all products for the organizer, set status to 'suspended'. The call is limited to users with the admin role.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="organizerKey">The key of the organizer</param>
        /// <param name="body">The organizer's status</param>
        /// <returns>void</returns>
        /// <exception cref="ApiException"></exception>
        public void updateOrganizer(string authorization, long? organizerKey, OrganizerStatus body)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (organizerKey == null)
                throw new ApiException("Required parameter organizerKey is null.");

            if (body == null)
                throw new ApiException("Required parameter body is null.");

            // create path and map variables
            var path = "/organizers/{organizerKey}"
                .Replace("{format}", "json")
                .Replace("{" + "organizerKey" + "}", apiInvoker.EscapeString(organizerKey.ToString()));

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes.Count > 0 ? contentTypes[0] : "application/json";

            apiInvoker.InvokeAPI(basePath, path, "PUT", queryParams, body, headerParams, formParams, typeof(void), contentType);
        }

        /// <summary>
        /// Get organizer by email
        /// Gets the individual organizer specified by the organizer's email address. This API call is only available to users with the admin role.
        /// </summary>
        /// <param name="authorization">Access token</param>
        /// <param name="email">The email address of the organizer</param>
        /// <returns>List&lt;Organizer&gt; </returns>
        /// <exception cref="ApiException"></exception>
        [Obsolete("Use getOrganizersAllOrByEmail() instead", false)]
        public List<Organizer> getOrganizerByEmail(string authorization, string email)
        {
            if (authorization == null)
                throw new ApiException("Required parameter authorization is null.");

            if (email == null)
                throw new ApiException("Required parameter email is null.");

            // create path and map variables
            var path = "/organizers"
                .Replace("{format}", "json");

            // query params
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, object>();

            if (email != null)
                queryParams.Add("email", email.Stringify());

            headerParams.Add("Authorization", authorization);

            var contentTypes = new List<string> { "application/json" };
            string contentType = contentTypes[0];

            var response = apiInvoker.InvokeAPI(basePath, path, "GET", queryParams, null, headerParams, formParams, typeof(List<Organizer>), contentType);
            if (response != null)
                return (List<Organizer>)response;

            return null;
        }

    }
}
